from typing import TypeVar, Generic

T = TypeVar('T')


class Singleton(Generic[T]):
    """
    A non-thread-safe helper class to ease implementing singletons.
    This should be used as a decorator -- not a metaclass -- to the
    class that should be a singleton.

    The decorated class can define one `__init__` function that
    takes only the `self` argument. Also, the decorated class cannot be
    inherited from. Other than that, there are no restrictions that apply
    to the decorated class.

    To get the singleton instance, use the `instance` method. Trying
    to use `__call__` will result in a `TypeError` being raised.

    """

    def __init__(self, decorated):
        self._decorated: T = decorated

    def get_instance(self) -> T:
        """
                Returns the singleton instance. Upon its first call, it creates a
                new instance of the decorated class and calls its `__init__` method.
                On all subsequent calls, the already created instance is returned.

                """
        try:
            return self._instance
        except AttributeError:
            self._instance: T = self._decorated()
            return self._instance

    @property
    def shared(self) -> T:
        return self.get_instance()

    @property
    def instance(self) -> T:
        return self.get_instance()

    @property
    def singleton(self) -> T:
        return self.get_instance()

    def __call__(self):
        raise TypeError('Singletons must be accessed through `instance()`.')
